Module gpu_types

Module gpu_types 

GPU resource wrappers that can be real or mock.

These types wrap WGPU resources and allow for both real GPU operations and mock implementations for testing.

Structs

GpuBindGroup
Wrapper around GPU bind group that can be real or mock.
GpuBindGroupLayout
Wrapper around GPU bind group layout that can be real or mock.
GpuBuffer
Wrapper around GPU buffer that can be real or mock.
GpuComputePipeline
Wrapper around GPU compute pipeline that can be real or mock.
GpuRenderPipeline
Wrapper around GPU render pipeline that can be real or mock.
GpuSampler
Wrapper around GPU sampler that can be real or mock.
GpuShaderModule
Wrapper around GPU shader module that can be real or mock.
GpuTexture
Wrapper around GPU texture that can be real or mock.